<?php

declare(strict_types=1);

namespace Drupal\schemadotorg_field_parts;

use Drupal\schemadotorg\SchemaDotOrgMappingInterface;

/**
 * Schema.org identifier manager interface.
 */
interface SchemaDotOrgFieldPartsManagerInterface {

  /**
   * The field prefix.
   */
  const PREFIX = 'prefix';

  /**
   * The field suffix.
   */
  const SUFFIX = 'suffix';

  /**
   * The field parts.
   */
  const PARTS = ['prefix', 'suffix'];

  /**
   * Add field parts to a Schema.org mappings' field before a mapping is saved.
   *
   * @param \Drupal\schemadotorg\SchemaDotOrgMappingInterface $mapping
   *   The Schema.org mapping.
   */
  public function mappingPresave(SchemaDotOrgMappingInterface $mapping): void;

  /**
   * Alter field storage and field values before they are created.
   *
   * @param string $schema_type
   *   The Schema.org type.
   * @param string $schema_property
   *   The Schema.org property.
   * @param array $field_storage_values
   *   Field storage config values.
   * @param array $field_values
   *   Field config values.
   * @param string|null $widget_id
   *   The plugin ID of the widget.
   * @param array $widget_settings
   *   An array of widget settings.
   * @param string|null $formatter_id
   *   The plugin ID of the formatter.
   * @param array $formatter_settings
   *   An array of formatter settings.
   */
  public function propertyFieldAlter(
    string $schema_type,
    string $schema_property,
    array &$field_storage_values,
    array &$field_values,
    ?string &$widget_id,
    array &$widget_settings,
    ?string &$formatter_id,
    array &$formatter_settings,
  ): void;

}
